@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import sys
-import textwrap
 from pathlib import Path
 
 import pkg_resources
@@ -11,6 +10,7 @@ from PySide6.QtUiTools import QUiLoader
 from PySide6.QtWidgets import QButtonGroup, QMainWindow, QFileDialog, QDialog
 
 from plagdef.gui.model import ResultsTableModel, DocumentPairMatches
+from plagdef.model.util import version
 
 UI_FILES = {
     'main_window': pkg_resources.resource_filename(__name__, 'ui/main_window.ui'),
@@ -30,6 +30,7 @@ class MainWindow:
         self._configure()
 
     def _configure(self):
+        self._window.setWindowTitle(f'PlagDef v{version()}')
         for view in self._views:
             self._window.stacked_widget.addWidget(view.widget)
 
@@ -55,96 +56,89 @@ class View:
 
 class HomeView(View):
     def __init__(self):
-        self.lang = None
-        self.recursive = False
         self.widget = _load_ui_file(Path(UI_FILES['home_widget']))
         self._configure()
 
     def _configure(self):
         self.widget.lang_button_group = QButtonGroup()
-        self.widget.lang_button_group.addButton(self.widget.eng_radio)
-        self.widget.lang_button_group.addButton(self.widget.ger_radio)
-        self.widget.open_folder_button.setCursor(QCursor(Qt.PointingHandCursor))
-        self.widget.detect_button.setCursor(QCursor(Qt.PointingHandCursor))
-        self.widget.folder_name_label.setVisible(False)
-        self.widget.recursive_check_box.setVisible(False)
-        self.widget.remove_folder_button.setCursor(QCursor(Qt.PointingHandCursor))
-        self.widget.remove_folder_button.setVisible(False)
-        self.widget.sel_lang_label.setVisible(False)
-        self.widget.change_lang_button.setCursor(QCursor(Qt.PointingHandCursor))
-        self.widget.change_lang_button.setVisible(False)
-        self.widget.exclude_common_check_box.setVisible(False)
+        self.widget.lang_button_group.addButton(self.widget.ger_button)
+        self.widget.lang_button_group.addButton(self.widget.eng_button)
+        [element.setVisible(False)
+         for element in (self.widget.archive_dir_label, self.widget.archive_rmdir_button, self.widget.docs_dir_label,
+                         self.widget.docs_rmdir_button, self.widget.common_dir_label, self.widget.common_rmdir_button)]
+        [button.setCursor(QCursor(Qt.PointingHandCursor))
+         for button in (self.widget.ger_button, self.widget.eng_button, self.widget.archive_dir_button,
+                        self.widget.docs_dir_button, self.widget.common_dir_button, self.widget.detect_button,
+                        self.widget.archive_rmdir_button, self.widget.docs_rmdir_button,
+                        self.widget.common_rmdir_button)]
 
-    def register_for_signals(self, open_folder=None, remove_folder=None, exclude_common=None, select_lang=None,
-                             reset_lang_sel=None, detect=None):
-        self.widget.open_folder_button.clicked.connect(lambda: open_folder())
-        self.widget.exclude_common_check_box.toggled.connect(lambda checked: exclude_common(checked))
-        self.widget.remove_folder_button.clicked.connect(lambda: remove_folder())
-        self.widget.lang_button_group.buttonClicked.connect(lambda: select_lang())
-        self.widget.change_lang_button.clicked.connect(lambda: reset_lang_sel())
+    @property
+    def archive_rec(self):
+        return self.widget.archive_rec_check_box.isChecked()
+
+    @property
+    def docs_rec(self):
+        return self.widget.docs_rec_check_box.isChecked()
+
+    @property
+    def common_rec(self):
+        return self.widget.common_rec_check_box.isChecked()
+
+    @property
+    def lang(self):
+        return 'ger' if self.widget.lang_button_group.checkedButton() == self.widget.ger_button else 'eng'
+
+    def register_for_signals(self, select_archive_dir=None, rm_archive_dir=None, select_docs_dir=None,
+                             rm_docs_dir=None, select_common_dir=None, rm_common_dir=None, detect=None):
+        self.widget.archive_dir_button.clicked.connect(lambda: select_archive_dir())
+        self.widget.archive_rmdir_button.clicked.connect(lambda: rm_archive_dir())
+        self.widget.docs_dir_button.clicked.connect(lambda: select_docs_dir())
+        self.widget.docs_rmdir_button.clicked.connect(lambda: rm_docs_dir())
+        self.widget.common_dir_button.clicked.connect(lambda: select_common_dir())
+        self.widget.common_rmdir_button.clicked.connect(lambda: rm_common_dir())
         self.widget.detect_button.clicked.connect(lambda: detect())
 
-    def folder_selected(self, folder_name: str):
-        self.widget.folder_name_label.setText(
-            f'<html><head/><body><p align="center"><span style="font-size:12pt; color:#ffffff;"> '
-            f'{folder_name}</span></p></body></html>')
-        self.widget.folder_name_label.setWordWrap(True)
-        self.widget.open_folder_button.setVisible(False)
-        self.widget.folder_name_label.setVisible(True)
-        self.widget.recursive_check_box.setVisible(True)
-        self.widget.remove_folder_button.setVisible(True)
-        [radio.setEnabled(True) for radio in self.widget.lang_button_group.buttons()]
+    def archive_dir_selected(self, folder_name: str):
+        self._dir_selected(folder_name, self.widget.archive_dir_button, self.widget.archive_rmdir_button,
+                           self.widget.archive_dir_label, 12)
 
-    def common_folder_selected(self, folder_name: str):
-        wrapped_name = textwrap.fill(folder_name, 20)
-        self.widget.exclude_common_check_box.setText(f'Excluding text in:\n{wrapped_name}')
+    def archive_dir_removed(self):
+        self._dir_removed(self.widget.archive_dir_button, self.widget.archive_rmdir_button,
+                          self.widget.archive_dir_label)
 
-    def reset_folder_selection(self):
-        self.recursive = False
-        self.widget.recursive_check_box.setChecked(False)
-        self.widget.open_folder_button.setVisible(True)
-        self.widget.folder_name_label.setVisible(False)
-        self.widget.recursive_check_box.setVisible(False)
-        self.widget.remove_folder_button.setVisible(False)
-        [radio.setEnabled(False) for radio in self.widget.lang_button_group.buttons()]
-
-    def language_selected(self):
-        self.recursive = self.widget.recursive_check_box.isChecked()
-        lang_long = self.widget.lang_button_group.checkedButton().text()
-        self.lang = lang_long[:3].lower()
-        self.widget.sel_lang_label.setText(
-            f'<html><head/><body><p align="center"><span style="font-size:12pt; color:#ffffff;"> '
-            f'{lang_long}</span></p></body></html>')
-        self.widget.recursive_check_box.setEnabled(False)
-        self.widget.remove_folder_button.setVisible(False)
-        [radio.setVisible(False) for radio in self.widget.lang_button_group.buttons()]
-        self.widget.sel_lang_label.setVisible(True)
-        self.widget.change_lang_button.setVisible(True)
+    def docs_dir_selected(self, folder_name: str):
+        self._dir_selected(folder_name, self.widget.docs_dir_button, self.widget.docs_rmdir_button,
+                           self.widget.docs_dir_label, 16)
         self.widget.detect_button.setEnabled(True)
-        self.widget.exclude_common_check_box.setVisible(True)
 
-    def reset_language_selection(self):
-        self.lang = None
-        self.widget.lang_button_group.setExclusive(False)
-        self.widget.lang_button_group.checkedButton().setChecked(False)
-        self.widget.lang_button_group.setExclusive(True)
+    def docs_dir_removed(self):
+        self._dir_removed(self.widget.docs_dir_button, self.widget.docs_rmdir_button, self.widget.docs_dir_label)
         self.widget.detect_button.setEnabled(False)
-        self.widget.exclude_common_check_box.setVisible(False)
-        self.reset_exclude_common()
-        self.widget.sel_lang_label.setVisible(False)
-        self.widget.change_lang_button.setVisible(False)
-        [radio.setVisible(True) for radio in self.widget.lang_button_group.buttons()]
-        self.widget.remove_folder_button.setVisible(True)
-        self.widget.recursive_check_box.setEnabled(True)
 
-    def reset_exclude_common(self):
-        self.widget.exclude_common_check_box.setChecked(False)
-        self.widget.exclude_common_check_box.setText('Exclude common text')
+    def common_dir_selected(self, folder_name: str):
+        self._dir_selected(folder_name, self.widget.common_dir_button, self.widget.common_rmdir_button,
+                           self.widget.common_dir_label, 12)
+
+    def common_dir_removed(self):
+        self._dir_removed(self.widget.common_dir_button, self.widget.common_rmdir_button, self.widget.common_dir_label)
+
+    def _dir_selected(self, folder_name: str, dir_button, rm_button, label, font_size: int):
+        dir_button.setEnabled(False)
+        label.setText(
+            f'<html><head/><body><p align="center"><span style="font-size:{font_size}pt; color:#ffffff;"> '
+            f'{folder_name}</span></p></body></html>')
+        label.setVisible(True)
+        rm_button.setVisible(True)
+
+    def _dir_removed(self, button, rm_button, label):
+        label.setVisible(False)
+        rm_button.setVisible(False)
+        button.setEnabled(True)
 
     def on_destroy(self):
-        self.reset_language_selection()
-        [radio.setEnabled(False) for radio in self.widget.lang_button_group.buttons()]
-        self.reset_folder_selection()
+        self.archive_dir_removed()
+        self.docs_dir_removed()
+        self.common_dir_removed()
 
 
 class FileDialog(QFileDialog):
