@@ -34,15 +34,16 @@ class Preprocessor:
     def _preprocess(self, doc: Document, nlp_model: Pipeline, common_word_lists: list[list[str]], stop_words: set[str]):
         sents = nlp_model(doc.text).sentences
         for sent_idx, sent in enumerate(sents):
-            non_punct_words = [word for word in sent.words if not word.upos == 'PUNCT' and len(word.text) > 1]
+            filtered_words = _word_filter(sent.words)
             if self._rem_stop_words:
-                sent_lemmas = [word.lemma for word in non_punct_words if word.text.lower() not in stop_words]
+                sent_lemmas = [word.lemma for word in filtered_words if word.text.lower() not in stop_words]
             else:
-                sent_lemmas = [word.lemma for word in non_punct_words]
+                sent_lemmas = [word.lemma for word in filtered_words]
             if len(sent_lemmas):
                 lemma_count = Counter(sent_lemmas)
                 sentence = Sentence(sent.tokens[0].start_char, sent.tokens[-1].end_char, lemma_count, doc)
-                sentence.words = _to_words(sent.tokens, sentence)
+                sentence.words = [Word(word.parent.start_char, word.parent.end_char, sentence)
+                                  for word in filtered_words]
                 doc.add_sent(sentence)
                 if _sent_contains_common_words(sentence.words, common_word_lists):
                     sentence.common = True
@@ -103,19 +104,13 @@ def _common_word_lists(pipe: Pipeline, common_docs: list[Document]) -> list[list
             parsed_line = pipe(line)
             line_words = []
             for sent in parsed_line.sentences:
-                [line_words.append(word.text.lower()) for word in filter(lambda w: not w.upos == 'PUNCT'
-                                                                                   and len(w.text) > 1, sent.words)]
+                [line_words.append(word.text.lower()) for word in _word_filter(sent.words)]
             common_word_lists.append(line_words) if len(line_words) else None
     return common_word_lists
 
 
-def _to_words(stanza_tokens, sentence: Sentence) -> list[Word]:
-    words = []
-    for stanza_token in stanza_tokens:
-        for stanza_word in stanza_token.words:
-            if not stanza_word.upos == 'PUNCT' and len(stanza_word.text) > 1:
-                words.append(Word(stanza_token.start_char, stanza_token.end_char, sentence))
-    return words
+def _word_filter(stanza_words: list) -> list:
+    return [word for word in stanza_words if not word.upos == 'PUNCT' and word.text.isalnum() and len(word.text) > 1]
 
 
 def _sent_contains_common_words(sent_words: list[Word], common_word_lists: list[list[str]]) -> bool:
