@@ -1,5 +1,10 @@
 from numpy import dot
 from numpy.linalg import norm
+from pkg_resources import get_distribution
+
+
+def version():
+    return get_distribution('plagdef').version
 
 
 def cos_sim(bow1: dict, bow2: dict):
